@@ -37,7 +37,7 @@
 //! outlive its parent (the task that spawned it), unless this parent is the root task.
 //!
 //! The root task can also wait on the completion of the child task; a call to [`spawn`] produces a
-//! [`JoinHandle`], which provides implements `Future` and can be `await`ed:
+//! [`JoinHandle`], which implements `Future` and can be `await`ed:
 //!
 //! ```
 //! use async_std::task;
@@ -58,7 +58,7 @@
 //! ## Configuring tasks
 //!
 //! A new task can be configured before it is spawned via the [`Builder`] type,
-//! which currently allows you to set the name and stack size for the child task:
+//! which currently allows you to set the name for the child task:
 //!
 //! ```
 //! # #![allow(unused_must_use)]
@@ -110,20 +110,24 @@
 //! [`join`]: struct.JoinHandle.html#method.join
 //! [`panic!`]: https://doc.rust-lang.org/std/macro.panic.html
 //! [`Builder`]: struct.Builder.html
-//! [`Builder::stack_size`]: struct.Builder.html#method.stack_size
 //! [`Builder::name`]: struct.Builder.html#method.name
 //! [`task::current`]: fn.current.html
-//! [`Task`]: struct.Thread.html
+//! [`Task`]: struct.Task.html
 //! [`Task::name`]: struct.Task.html#method.name
 //! [`task_local!`]: ../macro.task_local.html
 //! [`with`]: struct.LocalKey.html#method.with
 
-cfg_std! {
+cfg_alloc! {
     #[doc(inline)]
-    pub use std::task::{Context, Poll, Waker};
+    pub use core::task::{Context, Poll, Waker};
+    pub use ready::ready;
 
-    #[doc(inline)]
-    pub use async_macros::ready;
+    mod ready;
+}
+
+cfg_std! {
+    pub use yield_now::yield_now;
+    mod yield_now;
 }
 
 cfg_default! {
@@ -134,31 +138,37 @@ cfg_default! {
     pub use task_id::TaskId;
     pub use join_handle::JoinHandle;
     pub use sleep::sleep;
+    #[cfg(not(target_os = "unknown"))]
     pub use spawn::spawn;
     pub use task_local::{AccessError, LocalKey};
 
-    use builder::Runnable;
-    use task_local::LocalsMap;
+    pub(crate) use task_local::LocalsMap;
+    pub(crate) use task_locals_wrapper::TaskLocalsWrapper;
 
     mod block_on;
     mod builder;
     mod current;
-    mod executor;
     mod join_handle;
     mod sleep;
+    #[cfg(not(target_os = "unknown"))]
     mod spawn;
+    #[cfg(not(target_os = "unknown"))]
     mod spawn_blocking;
     mod task;
     mod task_id;
     mod task_local;
+    mod task_locals_wrapper;
 
+    #[cfg(not(target_os = "unknown"))]
     #[cfg(any(feature = "unstable", test))]
     pub use spawn_blocking::spawn_blocking;
+    #[cfg(not(target_os = "unknown"))]
     #[cfg(not(any(feature = "unstable", test)))]
     pub(crate) use spawn_blocking::spawn_blocking;
 }
 
 cfg_unstable! {
-    pub use yield_now::yield_now;
-    mod yield_now;
+    pub use spawn_local::spawn_local;
+
+    mod spawn_local;
 }
