@@ -1,4 +1,4 @@
-#![feature(async_await)]
+#![cfg(not(target_os = "unknown"))]
 
 use async_std::task;
 
